/**
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 *  strict-local
 * @format
 */

/* eslint-env worker, serviceworker */
"use strict";

const REVISION_ID_HEADER = "X-Metro-Delta-ID";

function getRevisionId(bundleRes) {
  const revisionId = bundleRes.headers.get(REVISION_ID_HEADER);

  if (revisionId == null) {
    if (__DEV__) {
      throw new Error(
        `The \`${REVISION_ID_HEADER}\` header should be present on bundle responses from the Metro server.`
      );
    } else {
      // This should never happen since we fully control the cache contents in
      // the production version of the delta client.
      throw new Error("The bundle cache is corrupted.");
    }
  }

  return revisionId;
}

function createResponse(contents, revisionId) {
  return new Response(contents, {
    headers: new Headers({
      "Cache-Control": "no-cache",
      [REVISION_ID_HEADER]: revisionId
    })
  });
}

module.exports = {
  createResponse,
  getRevisionId
};
